aboutsummaryrefslogtreecommitdiffstats
path: root/src/libstate/get_enc.cpp
diff options
context:
space:
mode:
authorlloyd <[email protected]>2010-07-09 15:06:31 +0000
committerlloyd <[email protected]>2010-07-09 15:06:31 +0000
commitf9162c355d3cee11be911c4cf469044b5c3c4699 (patch)
tree710c305d8e0f965543f56dc06ce2535c842fc524 /src/libstate/get_enc.cpp
parent14bfa0d15fc666b83a0b58a0713abba76c85dc41 (diff)
Rename S2K to PBKDF, because that is by far the most common name - S2K
really is only used by OpenPGP, and largely it was named S2K here because the OpenPGP S2K was implemented years before the ones in PKCS #5. We have a typedef of PBKDF to S2K, and an inlined get_s2k that calls get_pbkdf for source compatability. There doesn't seem to be any reason to have a forward for the renamed s2k.h header - to actually use a PBKDF, you'd have to either include lookup.h and call get_s2k / get_pbkdf, or else include an algorithm-specific header and use it directly. In either case, including s2k.h is neither necessary nor sufficient.
Diffstat (limited to 'src/libstate/get_enc.cpp')
-rw-r--r--src/libstate/get_enc.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/libstate/get_enc.cpp b/src/libstate/get_enc.cpp
index ab4d15896..a825a5d24 100644
--- a/src/libstate/get_enc.cpp
+++ b/src/libstate/get_enc.cpp
@@ -81,9 +81,9 @@
namespace Botan {
/*
* Get a S2K algorithm by name
*/
-S2K* get_s2k(const std::string& algo_spec)
+PBKDF* get_pbkdf(const std::string& algo_spec)
{
SCAN_Name request(algo_spec);
@@ -81,9 +81,9 @@
namespace Botan {
/*
-* Get a S2K algorithm by name
+* Get a PBKDF algorithm by name
*/